#!/usr/bin/env node
import * as yargs from 'yargs'

import * as conf from '../package.json'
import { errormsg, exitWithError, parseGitContext } from '../helpers'

const onError = (err: any) => {
    exitWithError(err)
}

process.on('uncaughtException', onError)
process.on('unhandledRejection', onError);

(async () => {
    return yargs
        .env('CF_')
        .option('gitContext', {
            description: 'The git-context object in json format',
            demand: errormsg`must provide "gitContext" object as a json object`,
        })
        .coerce({
            'gitContext': parseGitContext,
        })
        .wrap(Math.min(100, yargs.terminalWidth()))
        .scriptName(Object.keys(conf.bin)[0])
        .usage('Usage: $0 <command> [Options]')
        .commandDir('commands/root', {
            extensions: ['cmd.js', 'cmd.ts'],
        })
        .demandCommand(1, errormsg`need to use at least one command`)
        .version(conf.version)
        .argv
})()
