import { red } from 'chalk'

export const to = async (fn: any) => {
    try {
        let res
        if (typeof fn === 'function') {
            res = await fn()
        } else {
            res = await fn
        }
        return [null, res]
    } catch (err) {
        return [err, null]
    }
}

export const errormsg = (msg: TemplateStringsArray | string): string => {
    return red`error: ` + msg
}

export const exitWithError = (msg: TemplateStringsArray | string) => {
    console.log(errormsg(msg))
    process.exit(1)
}

export const parseGitContext = (gitContextStr: string): any => {
    const isBase64 = /^([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)?$/
    if (isBase64.test(gitContextStr)) {
        gitContextStr = Buffer.from(gitContextStr, 'base64').toString('utf-8')
    }

    try {
        const gitContext = JSON.parse(gitContextStr)
        return gitContext
    } catch (err) {
        exitWithError(`could not parse git context json, with error ${err}`)
    }
}