import { get } from 'lodash'
import {
    ProviderConstructor,
    Provider,
} from './types'

// tslint:disable-next-line no-var-requires
const CFError = require('cf-errors')

// Providers
import Github          from './github'
import Gitlab          from './gitlab'
import Bitbucket       from './bitbucket'
import BitbucketServer from './bitbucket-server'

const providers: { [key: string]: ProviderConstructor } = {
    'github': Github,
    'gitlab': Gitlab,
    'bitbucket': Bitbucket,
    'bitbucket-server': BitbucketServer,
}

const _getProviderModule = (providerName: string): ProviderConstructor => {
    const providerModule = providers[providerName]
    if (!providerModule) {
        throw new CFError(`Provider module cannot be found: ${providerName}`)
    }

    return providerModule
}

export async function getProviderByContext(gitContext: any): Promise<Provider> {
    const providerName = gitContext.spec.type.replace('git.', '')
    const providerOptions = get(gitContext, 'spec.data.auth', {}) as any

    const ProviderClass = _getProviderModule(providerName)
    return new ProviderClass(providerOptions)
}


export { Provider, Branch, Commit } from './types'
